%-------------------------------------------------------------------------%
% Copyright (c) 2018 Modenese L.                                          %
%                                                                         %
% Licensed under the Apache License, Version 2.0 (the "License");         %
% you may not use this file except in compliance with the License.        %
% You may obtain a copy of the License at                                 %
% http://www.apache.org/licenses/LICENSE-2.0.                             %
%                                                                         %
% Unless required by applicable law or agreed to in writing, software     %
% distributed under the License is distributed on an "AS IS" BASIS,       %
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or         %
% implied. See the License for the specific language governing            %
% permissions and limitations under the License.                          %
%                                                                         %
%    Author:   Luca Modenese, May 2016                                    %
%    email:    l.modenese@sheffield.ac.uk                                 %
% ----------------------------------------------------------------------- %
% This function simply removes blank spaces from the name of muscles. This
% was necessary at some point when we switched from NMSBuilder 0.1 to
% NMSBuilder 1.0.
%
% Inputs:
%    - osimModel: an openSim model (java object).
%
% Outputs:
%    - upd_osimModel: updated openSim model with deblanked muscles' names.
%                     This model is a clone of the original one.
%--------------------------------------------------------------------------
% last modified
% 25/04/2018, Luca Modenese
% Added comments
%--------------------------------------------------------------------------

function upd_osimModel = deblankMuscleNames(osimModel)

import org.opensim.modeling.*

% get muscle Set
mus = osimModel.getMuscles;

% deblank muscles
for n_m = 0:mus.getSize()-1
    deblanked_name = deblank(char(mus.get(n_m).getName()));
    mus.get(n_m).setName(deblanked_name)
end
% display
disp('Deblanked muscle names.')

% does not clone if there are constraints
upd_osimModel = osimModel.clone;

end

