%-------------------------------------------------------------------------%
% Copyright (c) 2018, Modenese L.                                         %
%                                                                         %
% Licensed under the Apache License, Version 2.0 (the "License");         %
% you may not use this file except in compliance with the License.        %
% You may obtain a copy of the License at                                 %
% http://www.apache.org/licenses/LICENSE-2.0.                             %
%                                                                         % 
% Unless required by applicable law or agreed to in writing, software     %
% distributed under the License is distributed on an "AS IS" BASIS,       %
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or         %
% implied. See the License for the specific language governing            %
% permissions and limitations under the License.                          %
%                                                                         %
%    Author:   Luca Modenese, 2016                                        %
%    email:    l.modenese@sheffield.ac.uk                                 % 
% ----------------------------------------------------------------------- %
%
% This function writes a txt file that can be imported by NMSBuilder using
% as input a matlab structure with fields colheades [1xn] and data [3xn].
%
% Inputs:
%    - LandmarkCloud: Matlab structure with two fields:
%                    * "colheaders": cell array containing names of N landmarks in the
%                     NMSBuilder landmark cloud.
%                    * "data": coordinates of the landmarks as a 3xN matrix. 
%
% Outputs:
%    - filename: file name (including path) of a txt file readable by
%                NMSBuilder v1.0 that includes the landmarks from the
%                LandmarkCloud structure.
% ----------------------------------------------------------------------- %
% Last updated 
% 05/04/2016, Erica Montefiori
% updated to NMSBuilder v1.0
% ----------------------------------------------------------------------- %
function writeNMSBuilderLandmarkCloud(LandmarkCloud,filename)

% opening the specified file
fid = fopen(filename,'w+');

% prints the default
%fprintf(fid,'Time 0\n');

% initializing upper bound
N_landmarks = size(LandmarkCloud.colheaders,2);

for n_L = 1:N_landmarks
    
    curr_name = LandmarkCloud.colheaders{n_L};    
    % check on length of marker name for compatibility with NMSBuilder 1.0 
    % (limit of 19 characters checked manually)
%     if length(curr_name)>=19
%         display(['Name ''', curr_name, ''' exceeds the maximum numbers of characters that NMSBuilder can read (19).']);
%         display(['The name will be shortened to ',curr_name(1:19),'.'])
%         curr_name = curr_name(1:19);
%     end
    
    % printing the data
    fprintf(fid,'%s, %6.4f, %6.4f, %6.4f\n', string(curr_name),LandmarkCloud.data(:,n_L)' );
end

% closing file
fclose(fid);

end


